% make weight histograms which have been averaged across simulations as
% well as across time (last few seconds of the simulation)

addpath(genpath('..'))

alltypes_vec = get_best16;
simnum_vec = (1:5);
layer = [1:33;34:66;67:99];
W_all = zeros(size(alltypes_vec,1),length(simnum_vec),99,99);

for i = 1:size(alltypes_vec,1)
    for j = 1:length(simnum_vec)
        load([num2str(alltypes_vec(i,:),'%1d'),'_sim',num2str(simnum_vec(j)),'.mat']);
        W_all(i,j,:,:) = mean(weights(:,:,5500:6000),3); % time average over last 5 seconds
%         W_all(i,j,:,:) = mean(weights(:,:,end),3); % does not time average
    end
end
for i = 1:99
    W_all(:,:,i,i) = NaN;
end
clearvars -except alltypes_vec simnum_vec layer W_all

%% Plot Histograms
color = [51,138,202]./255;
x = (0:0.01:1);
for i = 1:size(alltypes_vec,1)
    figure(i)
    set(gcf,'Position',[1977 210 1300 800])
    count=0;
    for j = 1:3
        for k = 1:3
            temp_hist = W_all(i,:,layer(j,:),layer(k,:));
            h = hist(temp_hist(:),x);
            h = h/sum(h);
            count=count+1;
            subplot(3,3,count)
            bar(x,h)
            title(['L',num2str(k),' --> L',num2str(j)],'FontSize',30)
            xlim([0 1]); ylim([0 0.5])
            xlabel('Weight','FontSize',30)
            set(gca,'FontSize',24)
            set(get(gca,'child'),'FaceColor',color,'EdgeColor',color);
        end
    end
    print([num2str(alltypes_vec(i,:),'%1d')],'-dpdf')
end
%% Figure S5: Multimodality within the top 16
save_plots = false;
multimodals = [4,8,12,16]; unimodals = [1,2,3,5,6,7,9,10,11,13,14,15];
W_multimodals = W_all(multimodals,:,:,:);
W_unimodals = W_all(unimodals,:,:,:);
color = [51,138,202]./255;
x = (0:0.01:1);
figure(101)
set(gcf,'Position',[1977 210 1300 800])
count=0;
for j = 1:3
    for k = 1:3
        temp_hist = W_multimodals(:,:,layer(j,:),layer(k,:));
        h = hist(temp_hist(:),x);
        h = h/sum(h);
        count=count+1;
        subplot(3,3,count)
        bar(x,h)
        title(['L',num2str(k),' --> L',num2str(j)],'FontSize',30)
        xlim([0 1]); ylim([0 0.2])
        xlabel('Weight','FontSize',30)
        set(gca,'FontSize',24)
        set(get(gca,'child'),'FaceColor',color,'EdgeColor',color);
    end
end
if save_plots
    print('Multimodals','-dpdf')
end

figure(102)
set(gcf,'Position',[1977 210 1300 800])
count=0;
for j = 1:3
    for k = 1:3
        temp_hist = W_unimodals(:,:,layer(j,:),layer(k,:));
        h = hist(temp_hist(:),x);
        h = h/sum(h);
        count=count+1;
        subplot(3,3,count)
        bar(x,h)
        title(['L',num2str(k),' --> L',num2str(j)],'FontSize',30)
        xlim([0 1]); ylim([0 0.2])
        xlabel('Weight','FontSize',30)
        set(gca,'FontSize',24)
        set(get(gca,'child'),'FaceColor',color,'EdgeColor',color);
    end
end
if save_plots
    print('Unimodals','-dpdf')
end

%%



















